@@ -1,38 +1,41 @@
 /*
     Copyright 2012  Dan Vratil <dan@progdan.cz>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
 
-    This program is distributed in the hope that it will be useful,
+    This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    GNU Lesser General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef LIBKGAPI_AUTHWIDGET_P_H
 #define LIBKGAPI_AUTHWIDGET_P_H
 
-#include <QtCore/QObject>
+#include <QObject>
 
 #include "ui/authwidget.h"
 #include "types.h"
 
 #include <QProgressBar>
 #include <QVBoxLayout>
-#include <QWebView>
+#include <QWebEngineView>
 #include <QLabel>
 
 namespace KGAPI2 {
 
 class Job;
 
-class WebView : public QWebView
+class WebView : public QWebEngineView
 {
     Q_OBJECT
 public:
@@ -40,18 +43,18 @@ public:
     ~WebView();
 
 protected:
-    void contextMenuEvent( QContextMenuEvent *);
+    void contextMenuEvent(QContextMenuEvent *) Q_DECL_OVERRIDE;
 };
 
 
-class Q_DECL_HIDDEN AuthWidget::Private: public QObject {
+class Q_DECL_HIDDEN AuthWidgetPrivate: public QObject {
 
     Q_OBJECT
 
   public:
-    explicit Private(AuthWidget *parent);
+    explicit AuthWidgetPrivate(AuthWidget *parent);
 
-    virtual ~Private();
+    virtual ~AuthWidgetPrivate();
 
     bool showProgressBar;
     QString username;
@@ -68,8 +71,6 @@ class Q_DECL_HIDDEN AuthWidget::Private: public QObject {
     QLabel *label;
 
   private Q_SLOTS:
-    void onSslError(QNetworkReply *reply, const QList<QSslError> &errors);
-
     void emitError(const KGAPI2::Error errCode, const QString &msg);
     void webviewUrlChanged(const QUrl &url);
     void webviewFinished(bool ok);
